<?php
   

class mt_testimonials extends WP_Widget { 

// constructor

   function __construct() {

		$widget_ops = array('classname' => 'mt_testimonials_widget', 'description' => __( 'What are people saying about you? Let everyone know.', 'mttestimonials') );

        parent::__construct(false, $name = __('MT - Testimonials', 'mttestimonials'), $widget_ops); 

		$this->alt_option_name = 'mt_testimonials_widget';

		

		add_action( 'save_post', array($this, 'flush_widget_cache') );

		add_action( 'deleted_post', array($this, 'flush_widget_cache') );

		add_action( 'switch_theme', array($this, 'flush_widget_cache') );		

    }

	

	// widget form creation

	function form($instance) {



	// Check values

		$title     		= isset( $instance['title'] ) ? wp_kses_post( $instance['title'] ) : ''; 	

		$number    		= isset( $instance['number'] ) ? intval( $instance['number'] ) : -1;
		
		$category    	= isset( $instance['category'] ) ? esc_html( $instance['category'] ) : '';
		
		$columnset    	= isset( $instance['columnset'] ) ? intval( $instance['columnset'] ) : 3;

		$see_all   		= isset( $instance['see_all'] ) ? esc_url_raw( $instance['see_all'] ) : '';

		$see_all_text  	= isset( $instance['see_all_text'] ) ? esc_html( $instance['see_all_text'] ) : '';

		$random 		= isset( $instance['random'] ) ? (bool) $instance['random'] : false;				

	?>



	<p><?php _e('In order to display this widget, you must first add some Testimonial custom post types.', 'mttestimonials'); ?></p> 

	<p>

	<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'mttestimonials'); ?></label>

	<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo wp_kses_post( $title ); ?>" />

	</p>


	<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of testimonials to show (-1 shows all):', 'mttestimonials' ); ?></label>

	<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo intval( $number ); ?>" size="3" /></p>
    
    <p><label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Category:', 'bldr' ); ?></label>

	<input class="widefat" id="<?php echo $this->get_field_id( 'category' ); ?>" name="<?php echo $this->get_field_name( 'category' ); ?>" type="text" value="<?php echo $category; ?>" size="3" /></p>
    
    
    <p><label for="<?php echo $this->get_field_id( 'columnset' ); ?>"><?php _e( 'Number of columns:', 'mttestimonials' ); ?></label>

	<input id="<?php echo $this->get_field_id( 'columnset' ); ?>" name="<?php echo $this->get_field_name( 'columnset' ); ?>" type="text" value="<?php echo intval( $columnset ); ?>" size="3" /></p>
    

    <p><label for="<?php echo $this->get_field_id('see_all'); ?>"><?php _e('Enter the URL for your Testimonials page:', 'mttestimonials'); ?></label>

	<input class="widefat custom_media_url" id="<?php echo $this->get_field_id( 'see_all' ); ?>" name="<?php echo $this->get_field_name( 'see_all' ); ?>" type="text" value="<?php echo esc_url_raw( $see_all ); ?>" size="3" /></p>	

    <p><label for="<?php echo $this->get_field_id('see_all_text'); ?>"><?php _e('Button Text (Default is set to <em>See All</em>:', 'mttestimonials'); ?></label>

	<input class="widefat" id="<?php echo $this->get_field_id( 'see_all_text' ); ?>" name="<?php echo $this->get_field_name( 'see_all_text' ); ?>" type="text" value="<?php echo esc_html( $see_all_text ); ?>" size="3" /></p>

	<p><input class="checkbox" type="checkbox" <?php checked( $random ); ?> id="<?php echo $this->get_field_id( 'random' ); ?>" name="<?php echo $this->get_field_name( 'random' ); ?>" />

	<label for="<?php echo $this->get_field_id( 'random' ); ?>"><?php _e( 'Show random Testimonials?', 'mttestimonials' ); ?></label></p>	



	<?php 

	}



	// update widget

	function update($new_instance, $old_instance) {

		$instance = $old_instance;

		$instance['title'] 			= wp_kses_post($new_instance['title']);

		$instance['number'] 		= intval($new_instance['number']);
		
		$instance['category'] 		= strip_tags($new_instance['category']);
		
		$instance['columnset'] 		= intval($new_instance['columnset']);	

		$instance['see_all'] 		= esc_url_raw( $new_instance['see_all'] );

		$instance['see_all_text'] 	= esc_html($new_instance['see_all_text']);

		$instance['random'] 		= isset( $new_instance['random'] ) ? (bool) $new_instance['random'] : false;	



		$this->flush_widget_cache();



		$alloptions = wp_cache_get( 'alloptions', 'options' );

		if ( isset($alloptions['mt_testimonials']) )

			delete_option('mt_testimonials');		  

		  

		return $instance;

	}

	

	function flush_widget_cache() {

		wp_cache_delete('mt_testimonials', 'widget');

	}

	

	// display widget

	function widget($args, $instance) {

		$cache = array();

		if ( ! $this->is_preview() ) {

			$cache = wp_cache_get( 'mt_testimonials', 'widget' );

		}



		if ( ! is_array( $cache ) ) {

			$cache = array();

		}



		if ( ! isset( $args['widget_id'] ) ) {

			$args['widget_id'] = $this->id;

		}



		if ( isset( $cache[ $args['widget_id'] ] ) ) {

			echo $cache[ $args['widget_id'] ];

			return;

		}



		ob_start();

		extract($args);



		$title = isset( $instance['title'] ) ? wp_kses_post($instance['title']) : ''; 

		$see_all 		= isset( $instance['see_all'] ) ? esc_url($instance['see_all']) : '';

		$see_all_text 	= isset( $instance['see_all_text'] ) ? esc_html($instance['see_all_text']) : '';
		
		$category 		= isset( $instance['category'] ) ? esc_html($instance['category']) : '';

		$number 		= ( ! empty( $instance['number'] ) ) ? intval( $instance['number'] ) : -1;

		if ( ! $number ) {

			$number = -1;

		}	
		
		$columnset 		= ( ! empty( $instance['columnset'] ) ) ? intval( $instance['columnset'] ) : 3;
		
		if ( ! $columnset ) {

			$columnset = 3;

		}
		

		$random 		= isset( $instance['random'] ) ? (bool) $instance['random'] : false;

		if ( $random ) {

			$random = 'rand';	

		} else {

			$random = 'date';

		}			



		$mt = new WP_Query(array(

			'no_found_rows'       => true,

			'post_status'         => 'publish',

			'post_type' 		  => 'testimonial',
			
			'category_name'       => $category,

			'posts_per_page'	  => $number,  

			'orderby'        	  => $random,			

		) );



		if ($mt->have_posts()) :

?>

		<section id="mt-testimonials">  
    	
        <?php if ( $title ) : ?> 
        
        	<div class="grid grid-pad"> 
        		<div class="col-1-1">
					<?php echo $before_title . $title . $after_title; ?>
                </div>
        	</div>
            
        <?php endif; ?>
        
    	<div class="grid grid-pad overflow">

				<?php while ( $mt->have_posts() ) : $mt->the_post(); ?>
               
				<div class="col-1-<?php if ( $columnset ) echo $columnset; ?> mt-column-clear">
            		<div class="testimonial">
            			<?php the_content( '<p>', '</p>' ); ?>
                		<?php the_post_thumbnail( 'thumbnail', array( 'class' => 'testimonial-img' ) ); ?> 
                		<h3><?php global $post; $text = get_post_meta( get_the_ID(), 'mt-full-name', true ); echo $text; ?></h3>
                		<span><?php global $post; $text = get_post_meta( get_the_ID(), 'mt-title-company', true ); echo $text; ?></span>
                	</div>
            	</div>

				<?php endwhile; ?>

			</div>

			<?php if ($see_all != '') : ?>

				<a href="<?php echo esc_url($see_all); ?>" class="featured-link"> 

					<?php if ($see_all_text) : ?>

						<button><?php echo esc_html( $see_all_text ); ?></button> 

					<?php else : ?>

						<button><?php echo __('See All', 'mtservices'); ?></button>

					<?php endif; ?>

				</a>

			<?php endif; ?>
		

		</section>		

	<?php

		// Reset the global $the_post as this query will have stomped on it

		wp_reset_postdata();



		endif;



		if ( ! $this->is_preview() ) {

			$cache[ $args['widget_id'] ] = ob_get_flush();

			wp_cache_set( 'mt_testimonials', $cache, 'widget' );

		} else {

			ob_end_flush(); 

		}

	}

	
}